select_word

Function select_word 

pub fn select_word<E: FieldOps>(elems: &[E], word: Word) -> E
WordIPVerifierChannel::select over a concrete word, for channels carrying Word.

Preconditions

  • elems must be non-empty and its length must be a power of two.